@@ -26,7 +26,7 @@ riskchart <- function(pr,
 
   # Riskcharts are only implemented for binary classificaton.
   
-  if (length(unique(ac)) > 2)
+  if (length(unique(na.omit(ac))) > 2)
     stop("Risk charts are for binary classification models only.")
   
   # 121209 Initialise variables otherwise appearing to be unintialised
